"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Recaptcha = void 0;

var _react = _interopRequireDefault(require("react"));

var _utils = require("./utils");

var load_callback = 'recaptcha_load_callback';
var click_callback = 'recaptcha_click_callback';

var Recaptcha = function Recaptcha(_ref) {
  var onChange = _ref.onChange,
      className = _ref.className,
      _ref$element_id = _ref.element_id,
      element_id = _ref$element_id === void 0 ? 'google-recaptcha' : _ref$element_id;

  window[click_callback] = function (r) {
    if (onChange) {
      onChange(r);
    } else {
      console.warn('no onChange for Recaptcha, response:', r);
    }
  };

  _react.default.useEffect(function () {
    function recaptcha_render() {
      window.grecaptcha.render(element_id, {
        sitekey: process.env.REACT_APP_RECAPTCHA_KEY,
        callback: click_callback
      });
    }

    if (window[load_callback]) {
      // recaptcha has already been loaded
      try {
        recaptcha_render();
      } catch (error) {
        // already rendered is ok, ignore
        if (error.message !== 'reCAPTCHA has already been rendered in this element') {
          throw error;
        }
      }

      window.grecaptcha.reset();
    } else {
      window[load_callback] = recaptcha_render;
      (0, _utils.load_script)("https://www.google.com/recaptcha/api.js?onload=".concat(load_callback, "&render=explicit"));
    }
  }, []);

  return /*#__PURE__*/_react.default.createElement("div", {
    className: className,
    id: element_id
  });
};

exports.Recaptcha = Recaptcha;