"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.prep_choice = prep_choice;
exports.InputWrapper = exports.HiddenInput = exports.InputFile = exports.InputRecaptcha = exports.InputDatetime = exports.InputTime = exports.InputDate = exports.InputNumber = exports.InputInteger = exports.InputToggle = exports.InputRadio = exports.InputCheckboxMultiple = exports.InputSelect = exports.InputCheckbox = exports.InputGeneral = exports.InvisibleInput = exports.InputHelpText = exports.InputLabel = void 0;

var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));

var _toConsumableArray2 = _interopRequireDefault(require("@babel/runtime/helpers/toConsumableArray"));

var _typeof2 = _interopRequireDefault(require("@babel/runtime/helpers/typeof"));

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _objectWithoutProperties2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutProperties"));

var _react = _interopRequireDefault(require("react"));

var _reactstrap = require("reactstrap");

var _utils = require("../utils");

var _Recaptcha = require("../Recaptcha");

var InputLabel = function InputLabel(_ref) {
  var field = _ref.field,
      children = _ref.children;
  return field.show_label !== false ? /*#__PURE__*/_react.default.createElement(_reactstrap.Label, {
    htmlFor: field.name,
    className: field.required ? 'required' : ''
  }, children, field.title) : null;
};

exports.InputLabel = InputLabel;

var InputHelpText = function InputHelpText(_ref2) {
  var field = _ref2.field;
  return field.help_text ? /*#__PURE__*/_react.default.createElement(_reactstrap.FormText, null, field.help_text) : null;
}; // used when a field is needed for html form validation but it should not be shown


exports.InputHelpText = InputHelpText;

var InvisibleInput = function InvisibleInput(_ref3) {
  var field = _ref3.field,
      disabled = _ref3.disabled,
      error = _ref3.error,
      value = _ref3.value,
      _onChange = _ref3.onChange,
      _onBlur = _ref3.onBlur;
  return /*#__PURE__*/_react.default.createElement(_reactstrap.Input, {
    className: "invisible-input",
    value: value || '',
    invalid: !!error,
    disabled: disabled,
    name: field.name,
    id: field.name,
    onChange: function onChange(e) {
      return _onChange(e.target.value);
    },
    onBlur: function onBlur(e) {
      return _onBlur(e.target.value);
    },
    required: field.required
  });
};

exports.InvisibleInput = InvisibleInput;

var placeholder = function placeholder(field) {
  if (field.placeholder === true) {
    return field.title;
  } else if (field.placeholder) {
    return field.placeholder;
  }

  return null;
};

var not_null_undefined = function not_null_undefined(v) {
  if (v === null || v === undefined) {
    return '';
  } else {
    return v;
  }
};

var InputGeneral = function InputGeneral(_ref4) {
  var className = _ref4.className,
      field = _ref4.field,
      error = _ref4.error,
      disabled = _ref4.disabled,
      value = _ref4.value,
      _onChange2 = _ref4.onChange,
      _onBlur2 = _ref4.onBlur,
      custom_type = _ref4.custom_type,
      extra = (0, _objectWithoutProperties2.default)(_ref4, ["className", "field", "error", "disabled", "value", "onChange", "onBlur", "custom_type"]);
  return /*#__PURE__*/_react.default.createElement(_reactstrap.FormGroup, {
    className: className || field.className
  }, /*#__PURE__*/_react.default.createElement(InputLabel, {
    field: field
  }), /*#__PURE__*/_react.default.createElement(_reactstrap.Input, (0, _extends2.default)({
    type: custom_type || field.type || 'text',
    className: field.inputClassName,
    invalid: !!error,
    disabled: disabled,
    name: field.name,
    id: field.name,
    required: field.required,
    maxLength: field.max_length,
    minLength: field.min_length,
    autoComplete: field.autocomplete,
    placeholder: placeholder(field),
    value: not_null_undefined(value),
    onChange: function onChange(e) {
      return _onChange2(e.target.value);
    },
    onBlur: function onBlur(e) {
      return _onBlur2(e.target.value);
    }
  }, extra)), error && /*#__PURE__*/_react.default.createElement(_reactstrap.FormFeedback, null, error), /*#__PURE__*/_react.default.createElement(InputHelpText, {
    field: field
  }));
};

exports.InputGeneral = InputGeneral;

var InputCheckbox = function InputCheckbox(_ref5) {
  var className = _ref5.className,
      field = _ref5.field,
      disabled = _ref5.disabled,
      value = _ref5.value,
      _onChange3 = _ref5.onChange,
      _onBlur3 = _ref5.onBlur,
      extra = (0, _objectWithoutProperties2.default)(_ref5, ["className", "field", "disabled", "value", "onChange", "onBlur"]);
  return /*#__PURE__*/_react.default.createElement(_reactstrap.FormGroup, {
    className: className || field.className || 'py-2',
    check: true
  }, /*#__PURE__*/_react.default.createElement(InputLabel, {
    field: field
  }, /*#__PURE__*/_react.default.createElement(_reactstrap.Input, (0, _extends2.default)({
    type: "checkbox",
    label: field.title,
    disabled: disabled,
    name: field.name,
    id: field.name,
    required: field.required,
    checked: value || false,
    onChange: function onChange(e) {
      return _onChange3(e.target.checked);
    },
    onBlur: function onBlur(e) {
      return _onBlur3(e.target.checked);
    }
  }, extra))), /*#__PURE__*/_react.default.createElement(InputHelpText, {
    field: field
  }));
};

exports.InputCheckbox = InputCheckbox;

function prep_choice(c) {
  if (typeof c === 'string') {
    c = {
      value: c
    };
  }

  if ((0, _typeof2.default)(c) !== 'object' || typeof c.value !== 'string') {
    throw TypeError("choice not an object or choice.value not a string: ".concat(c));
  }

  return {
    value: c.value,
    label: c.label || (0, _utils.as_title)(c.value)
  };
}

var InputSelect = function InputSelect(_ref6) {
  var className = _ref6.className,
      field = _ref6.field,
      disabled = _ref6.disabled,
      error = _ref6.error,
      value = _ref6.value,
      _onChange4 = _ref6.onChange,
      _onBlur4 = _ref6.onBlur,
      extra = (0, _objectWithoutProperties2.default)(_ref6, ["className", "field", "disabled", "error", "value", "onChange", "onBlur"]);
  return /*#__PURE__*/_react.default.createElement(_reactstrap.FormGroup, {
    className: className || field.className
  }, /*#__PURE__*/_react.default.createElement(InputLabel, {
    field: field
  }), /*#__PURE__*/_react.default.createElement(_reactstrap.CustomInput, (0, _extends2.default)({
    type: "select",
    invalid: !!error,
    value: value || '',
    disabled: disabled,
    name: field.name,
    id: field.name,
    required: field.required,
    autoComplete: field.autocomplete,
    onChange: function onChange(e) {
      return _onChange4(e.target.value);
    },
    onBlur: function onBlur(e) {
      return _onBlur4(e.target.value);
    }
  }, extra), field.allow_empty !== false && /*#__PURE__*/_react.default.createElement("option", {
    value: ""
  }, "\u2014"), field.choices && field.choices.map(prep_choice).map(function (c, i) {
    return /*#__PURE__*/_react.default.createElement("option", {
      key: i,
      value: c.value
    }, c.label);
  })), error && /*#__PURE__*/_react.default.createElement(_reactstrap.FormFeedback, null, error), /*#__PURE__*/_react.default.createElement(InputHelpText, {
    field: field
  }));
};

exports.InputSelect = InputSelect;

var InputCheckboxMultiple = function InputCheckboxMultiple(_ref7) {
  var className = _ref7.className,
      field = _ref7.field,
      disabled = _ref7.disabled,
      value = _ref7.value,
      onChange = _ref7.onChange,
      _onBlur5 = _ref7.onBlur,
      error = _ref7.error,
      extra = (0, _objectWithoutProperties2.default)(_ref7, ["className", "field", "disabled", "value", "onChange", "onBlur", "error"]);
  var selected = new Set(value || []);

  var onSingleChange = function onSingleChange(key) {
    if (!selected.delete(key)) {
      selected.add(key);
    }

    onChange((0, _toConsumableArray2.default)(selected));
  };

  return /*#__PURE__*/_react.default.createElement(_reactstrap.FormGroup, {
    className: className || field.className || 'checkbox-multiple'
  }, /*#__PURE__*/_react.default.createElement(InputLabel, {
    field: field
  }), field.choices && field.choices.map(prep_choice).map(function (c, i) {
    return /*#__PURE__*/_react.default.createElement("div", {
      key: i,
      className: "form-check"
    }, /*#__PURE__*/_react.default.createElement(_reactstrap.Label, {
      htmlFor: "".concat(field.name, "-").concat(c.value)
    }, /*#__PURE__*/_react.default.createElement(_reactstrap.Input, (0, _extends2.default)({
      type: "checkbox",
      label: c.label,
      disabled: disabled,
      name: "".concat(field.name, "-").concat(c.value),
      id: "".concat(field.name, "-").concat(c.value),
      checked: selected.has(c.value),
      onChange: function onChange() {
        return onSingleChange(c.value);
      },
      onBlur: function onBlur(e) {
        return _onBlur5(e.target.checked);
      }
    }, extra)), c.label));
  }), /*#__PURE__*/_react.default.createElement(InvisibleInput, {
    field: field,
    disabled: disabled,
    error: error,
    value: (value || []).join(','),
    onChange: onChange,
    onBlur: _onBlur5
  }), /*#__PURE__*/_react.default.createElement(InputHelpText, {
    field: field
  }), error && /*#__PURE__*/_react.default.createElement(_reactstrap.FormFeedback, null, error));
};

exports.InputCheckboxMultiple = InputCheckboxMultiple;

var InputRadio = function InputRadio(_ref8) {
  var className = _ref8.className,
      field = _ref8.field,
      disabled = _ref8.disabled,
      error = _ref8.error,
      value = _ref8.value,
      _onChange5 = _ref8.onChange,
      _onBlur6 = _ref8.onBlur,
      extra = (0, _objectWithoutProperties2.default)(_ref8, ["className", "field", "disabled", "error", "value", "onChange", "onBlur"]);
  return /*#__PURE__*/_react.default.createElement(_reactstrap.FormGroup, {
    className: className || field.className
  }, /*#__PURE__*/_react.default.createElement(InputLabel, {
    field: field
  }), field.choices && field.choices.map(prep_choice).map(function (c, i) {
    return /*#__PURE__*/_react.default.createElement("div", {
      key: i,
      className: "custom-control custom-radio"
    }, /*#__PURE__*/_react.default.createElement(_reactstrap.Input, (0, _extends2.default)({
      type: "radio",
      className: "custom-control-input",
      checked: c.value === value,
      disabled: disabled,
      name: field.name,
      id: "".concat(field.name, "-").concat(c.value),
      required: field.required,
      onChange: function onChange() {
        return _onChange5(c.value);
      },
      onBlur: function onBlur() {
        return _onBlur6(c.value);
      }
    }, extra)), /*#__PURE__*/_react.default.createElement("label", {
      className: "custom-control-label",
      htmlFor: "".concat(field.name, "-").concat(c.value)
    }, /*#__PURE__*/_react.default.createElement("span", {
      className: "d-inline-block mr-1"
    }, c.label.title || c.label), c.label.description && /*#__PURE__*/_react.default.createElement("small", {
      className: "text-muted"
    }, c.label.description)));
  }), error && /*#__PURE__*/_react.default.createElement(_reactstrap.FormFeedback, {
    className: "d-block"
  }, error), /*#__PURE__*/_react.default.createElement(InputHelpText, {
    field: field
  }));
};

exports.InputRadio = InputRadio;

var InputToggle = function InputToggle(_ref9) {
  var className = _ref9.className,
      field = _ref9.field,
      disabled = _ref9.disabled,
      error = _ref9.error,
      value = _ref9.value,
      onChange = _ref9.onChange,
      onBlur = _ref9.onBlur,
      children = _ref9.children,
      extra = (0, _objectWithoutProperties2.default)(_ref9, ["className", "field", "disabled", "error", "value", "onChange", "onBlur", "children"]);
  return /*#__PURE__*/_react.default.createElement(_reactstrap.FormGroup, {
    className: className || field.className
  }, /*#__PURE__*/_react.default.createElement(InputLabel, {
    field: field
  }), /*#__PURE__*/_react.default.createElement("div", null, /*#__PURE__*/_react.default.createElement(_reactstrap.ButtonGroup, null, field.choices && field.choices.map(prep_choice).map(function (c, i) {
    return /*#__PURE__*/_react.default.createElement(_reactstrap.Button, (0, _extends2.default)({
      key: i,
      disabled: disabled,
      onClick: function onClick() {
        return onChange(c.value);
      },
      color: c.value === value ? 'primary' : 'secondary'
    }, extra), c.label);
  }), children)), /*#__PURE__*/_react.default.createElement(InvisibleInput, {
    field: field,
    disabled: disabled,
    error: error,
    value: value,
    onChange: onChange,
    onBlur: onBlur
  }), error && /*#__PURE__*/_react.default.createElement(_reactstrap.FormFeedback, null, error), /*#__PURE__*/_react.default.createElement(InputHelpText, {
    field: field
  }));
};

exports.InputToggle = InputToggle;

var InputInteger = function InputInteger(props) {
  return /*#__PURE__*/_react.default.createElement(InputGeneral, (0, _extends2.default)({}, props, {
    custom_type: "number",
    step: "1",
    min: props.field.min,
    max: props.field.max,
    onChange: function onChange(v) {
      return props.onChange(v ? parseInt(v) : null);
    }
  }));
};

exports.InputInteger = InputInteger;

var InputNumber = function InputNumber(props) {
  return /*#__PURE__*/_react.default.createElement(InputGeneral, (0, _extends2.default)({}, props, {
    custom_type: "number",
    step: props.field.step,
    min: props.field.min,
    max: props.field.max,
    onChange: function onChange(v) {
      return props.onChange(v ? parseFloat(v) : null);
    }
  }));
};

exports.InputNumber = InputNumber;
var date_placeholder = 'dd/mm/yyyy';
var date_pattern = '([0-2]\\d|30|31)/(0\\d|10|11|12)/(19|20)\\d{2}'; // placeholder is useful here to provide partial support for safari which doesn't support date inputs

var InputDate = function InputDate(props) {
  return /*#__PURE__*/_react.default.createElement(InputGeneral, (0, _extends2.default)({}, props, {
    custom_type: "date",
    min: props.field.min,
    max: props.field.max,
    placeholder: props.field.placeholder || date_placeholder,
    pattern: props.field.pattern || date_pattern
  }));
};

exports.InputDate = InputDate;
var time_placeholder = 'HH:MM';
var time_pattern = '([01]\\d|2[0-3])[-:.][0-5]\\d';

var InputTime = function InputTime(props) {
  return /*#__PURE__*/_react.default.createElement(InputGeneral, (0, _extends2.default)({}, props, {
    custom_type: "time",
    min: props.field.min,
    max: props.field.max,
    placeholder: props.field.placeholder || time_placeholder,
    pattern: props.field.pattern || time_pattern
  }));
};

exports.InputTime = InputTime;

var pad2 = function pad2(number) {
  return Math.abs(number).toString().padStart(2, '0');
}; // NOTE: getTimezoneOffset is the opposite way round from normal TZ offsets, e.g. in BST getTimezoneOffset() gives -60


var display_offset = function display_offset(offset) {
  return "".concat(offset > 0 ? '-' : '+').concat(pad2(offset / 60), ":").concat(pad2(offset % 60));
};

var InputDatetime = function InputDatetime(_ref10) {
  var className = _ref10.className,
      field = _ref10.field,
      error = _ref10.error,
      disabled = _ref10.disabled,
      value = _ref10.value,
      onChange = _ref10.onChange,
      _onBlur7 = _ref10.onBlur,
      custom_type = _ref10.custom_type,
      extra = (0, _objectWithoutProperties2.default)(_ref10, ["className", "field", "error", "disabled", "value", "onChange", "onBlur", "custom_type"]);
  var date = '',
      time = '';

  if (value) {
    var m = value.match(/([^T]*)T([^+-]*)/);

    if (m) {
      var _m = (0, _slicedToArray2.default)(m, 3);

      date = _m[1];
      time = _m[2];
    }
  }

  var update = function update(date_, time_) {
    date_ = date_ || date;
    time_ = time_ || time;
    var ts_string = "".concat(date_, "T").concat(time_);
    var tz_offset = new Date(Date.parse(ts_string)).getTimezoneOffset();

    if (isNaN(tz_offset)) {
      // not yet a valid datetime, but we need to update it so the field changes
      onChange(ts_string);
    } else {
      onChange(ts_string + display_offset(tz_offset));
    }
  };

  return /*#__PURE__*/_react.default.createElement(_reactstrap.FormGroup, {
    className: className || field.className
  }, /*#__PURE__*/_react.default.createElement(InputLabel, {
    field: field
  }), /*#__PURE__*/_react.default.createElement(_reactstrap.InputGroup, null, /*#__PURE__*/_react.default.createElement(_reactstrap.Input, (0, _extends2.default)({
    type: "date",
    min: field.min,
    max: field.max,
    placeholder: field.placeholder || date_placeholder,
    pattern: field.pattern || date_pattern,
    className: field.inputClassName,
    invalid: !!error,
    disabled: disabled,
    name: "".concat(field.name, "-date"),
    id: "".concat(field.name, "-date"),
    required: field.required,
    autoComplete: field.autocomplete,
    value: date,
    onChange: function onChange(e) {
      return update(e.target.value);
    },
    onBlur: function onBlur(e) {
      return _onBlur7(e.target.value);
    }
  }, extra)), /*#__PURE__*/_react.default.createElement(_reactstrap.Input, (0, _extends2.default)({
    type: "time",
    placeholder: field.placeholder || time_placeholder,
    pattern: field.pattern || time_pattern,
    className: field.inputClassName,
    invalid: !!error,
    disabled: disabled,
    name: "".concat(field.name, "-time"),
    id: "".concat(field.name, "-time"),
    required: field.required,
    autoComplete: field.autocomplete,
    value: time,
    onChange: function onChange(e) {
      return update(null, e.target.value);
    },
    onBlur: function onBlur(e) {
      return _onBlur7(e.target.value);
    }
  }, extra))), error && /*#__PURE__*/_react.default.createElement(_reactstrap.FormFeedback, {
    className: "d-block"
  }, error), /*#__PURE__*/_react.default.createElement(InputHelpText, {
    field: field
  }));
};

exports.InputDatetime = InputDatetime;

var InputRecaptcha = function InputRecaptcha(_ref11) {
  var className = _ref11.className,
      field = _ref11.field,
      value = _ref11.value,
      error = _ref11.error,
      onChange = _ref11.onChange;

  _react.default.useEffect(function () {
    if (!value && window.grecaptcha) {
      window.grecaptcha.reset();
    }
  }, [value]);

  return /*#__PURE__*/_react.default.createElement(_reactstrap.FormGroup, {
    className: className || field.className
  }, /*#__PURE__*/_react.default.createElement(_Recaptcha.Recaptcha, {
    onChange: onChange,
    element_id: field.name
  }), error && /*#__PURE__*/_react.default.createElement(_reactstrap.FormFeedback, {
    className: "d-block"
  }, error), /*#__PURE__*/_react.default.createElement(InputHelpText, {
    field: field
  }));
};

exports.InputRecaptcha = InputRecaptcha;

var InputFile = function InputFile(_ref12) {
  var className = _ref12.className,
      field = _ref12.field,
      error = _ref12.error,
      disabled = _ref12.disabled,
      onChange = _ref12.onChange,
      value = _ref12.value,
      extra = (0, _objectWithoutProperties2.default)(_ref12, ["className", "field", "error", "disabled", "onChange", "value"]);

  var _React$useState = _react.default.useState(null),
      _React$useState2 = (0, _slicedToArray2.default)(_React$useState, 2),
      filename = _React$useState2[0],
      setFilename = _React$useState2[1];

  var _React$useState3 = _react.default.useState(null),
      _React$useState4 = (0, _slicedToArray2.default)(_React$useState3, 2),
      local_error = _React$useState4[0],
      setError = _React$useState4[1];

  var onFileChange = function onFileChange(e) {
    var file = e.target.files[0];
    setFilename(file.name);

    if (field.file_types && !field.file_types.includes(file.type)) {
      setError("Unexpected file type ".concat(file.type, ", expected ").concat(field.file_types.join(', ')));
      onChange(null);
    } else {
      setError(null);
      var reader = new FileReader();

      reader.onload = function () {
        return onChange({
          name: file.name,
          last_modified: file.lastModified,
          content: reader.result
        });
      };

      if (field.binary_data) {
        reader.readAsDataURL(file);
      } else {
        reader.readAsText(file);
      }
    }
  };

  if (local_error) {
    if (error) {
      error += ', ' + local_error;
    } else {
      error = local_error;
    }
  }

  return /*#__PURE__*/_react.default.createElement(_reactstrap.FormGroup, {
    className: className || field.className
  }, /*#__PURE__*/_react.default.createElement(InputLabel, {
    field: field
  }), /*#__PURE__*/_react.default.createElement("div", {
    className: "custom-file"
  }, /*#__PURE__*/_react.default.createElement(_reactstrap.Input, (0, _extends2.default)({
    type: "file",
    className: "custom-file-input",
    invalid: !!error,
    disabled: disabled,
    name: field.name,
    id: field.name,
    required: field.required,
    onChange: function onChange(e) {
      return onFileChange(e);
    }
  }, extra)), /*#__PURE__*/_react.default.createElement("label", {
    className: "custom-file-label",
    htmlFor: field.name
  }, filename || placeholder(field) || 'Choose file...')), error && /*#__PURE__*/_react.default.createElement(_reactstrap.FormFeedback, {
    className: "d-block"
  }, error), /*#__PURE__*/_react.default.createElement(InputHelpText, {
    field: field
  }));
};

exports.InputFile = InputFile;

var HiddenInput = function HiddenInput(_ref13) {
  var field = _ref13.field,
      error = _ref13.error,
      value = _ref13.value,
      _onChange6 = _ref13.onChange,
      extra = (0, _objectWithoutProperties2.default)(_ref13, ["field", "error", "value", "onChange"]);
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_reactstrap.Input, (0, _extends2.default)({
    type: "hidden",
    value: value || '',
    invalid: !!error,
    name: field.name,
    id: field.name,
    onChange: function onChange(e) {
      return _onChange6(e.target.value);
    },
    required: field.required
  }, extra)), error && /*#__PURE__*/_react.default.createElement(_reactstrap.FormFeedback, null, (0, _utils.as_title)(field.name), ": ", error));
};

exports.HiddenInput = HiddenInput;
var INPUT_LOOKUP = {
  bool: InputCheckbox,
  select: InputSelect,
  checkboxes: InputCheckboxMultiple,
  toggle: InputToggle,
  radio: InputRadio,
  int: InputInteger,
  number: InputNumber,
  date: InputDate,
  time: InputTime,
  datetime: InputDatetime,
  recaptcha: InputRecaptcha,
  file: InputFile,
  hidden: HiddenInput
};

var InputWrapper = function InputWrapper(_ref14) {
  var field = _ref14.field,
      value = _ref14.value,
      type_lookup = _ref14.type_lookup,
      props = (0, _objectWithoutProperties2.default)(_ref14, ["field", "value", "type_lookup"]);
  var InputComp = type_lookup && type_lookup[field.type] || INPUT_LOOKUP[field.type] || InputGeneral;

  var _React$useState5 = _react.default.useState(false),
      _React$useState6 = (0, _slicedToArray2.default)(_React$useState5, 2),
      focused = _React$useState6[0],
      setFocused = _React$useState6[1];

  var focus = field.focus;

  var inputRef = /*#__PURE__*/_react.default.createRef();

  _react.default.useEffect(function () {
    if (focus && !focused && inputRef.current) {
      inputRef.current.focus();
      setFocused(true);
    }
  }, [focus, inputRef]);

  field.title = field.title || (0, _utils.as_title)(field.name);
  return /*#__PURE__*/_react.default.createElement(InputComp, (0, _extends2.default)({
    field: field,
    value: [null, undefined].includes(value) ? field.default : value,
    innerRef: inputRef
  }, props));
};

exports.InputWrapper = InputWrapper;