"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Notify = void 0;

var _classCallCheck2 = _interopRequireDefault(require("@babel/runtime/helpers/classCallCheck"));

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _toast = require("./toast");

var now = function now() {
  return new Date();
};

var Notify = function Notify(history, browser_inactive_time) {
  var _this = this;

  (0, _classCallCheck2.default)(this, Notify);
  (0, _defineProperty2.default)(this, "request", function () {
    if (!('Notification' in window)) {
      console.warn('This browser does not support desktop notification');
    } else if (Notification.permission === 'default') {
      Notification.requestPermission();
    }
  });
  (0, _defineProperty2.default)(this, "notify", function (msg) {
    if (!('Notification' in window)) {
      console.warn('This browser does not support desktop notification');
    } else if (Notification.permission === 'granted') {
      _this._show_notification(msg);

      return;
    } else {
      console.warn('notifications not permitted');
    }

    _this._toast(msg);
  });
  (0, _defineProperty2.default)(this, "window_active", function () {
    return !document.hidden && now() - _this.last_event < _this.browser_inactive_time;
  });
  (0, _defineProperty2.default)(this, "_on_event", function () {
    _this.last_event = now();
  });
  (0, _defineProperty2.default)(this, "_show_notification", function (msg) {
    if (_this.window_active()) {
      _this._toast(msg);
    } else {
      var n = new Notification(msg.title, {
        body: msg.message || msg.body,
        icon: msg.icon,
        badge: msg.badge
      });

      n.onclick = function () {
        n.close();
        window.focus();
        var link = msg.link || (msg.data || {}).link;

        if (link) {
          _this.history.push(link);
        }
      };
    }
  });
  (0, _defineProperty2.default)(this, "_toast", function (msg) {
    var onClick = function onClick(e) {
      e.close();
      var link = msg.link || (msg.data || {}).link;

      if (link) {
        _this.history.push(link);
      }
    };

    (0, _toast.message_toast)(Object.assign({
      onClick: onClick,
      progress: false
    }, msg));
  });
  this.history = history;
  this.last_event = now();
  this.browser_inactive_time = browser_inactive_time || 5000;
  document.addEventListener('keydown', this._on_event);
  document.addEventListener('mousemove', this._on_event);
};

exports.Notify = Notify;